dhcpkit.ipv6.server.extensions.sol_max_rt.config module
=======================================================

.. automodule:: dhcpkit.ipv6.server.extensions.sol_max_rt.config
    :members:
    :undoc-members:
    :show-inheritance:
